===================
Project Information
===================

The **GGCE** software is released under the permissive 3-clause BSD-style license, with copyright attributed to the core authors of the software, accounting for both software development and intellectual contributions: Matthew R. Carbone, Stepan Fomichev and John Sous.

.. toctree::
   :maxdepth: 1

   project/authors.rst
   project/funding.rst

